@@ -11,6 +11,7 @@
 #' @param to End date as \code{yyyy-mm-dd}, \code{yyyy-mm} or \code{yyyy}.
 #' @param check.package Logical. Validate and "spell check" package.
 #' @param dev.mode Logical. Use validatePackage0() to scrape CRAN.
+#' @param fix.cranlogs Logical. Use RStudio logs to fix 8 dates with duplicated data in 'cranlogs' results.
 #' @export
 #' @examples
 #' \dontrun{
@@ -29,7 +30,7 @@
 #' }
 
 cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
-  to = NULL, check.package = TRUE, dev.mode = FALSE) {
+  to = NULL, check.package = TRUE, dev.mode = FALSE, fix.cranlogs = TRUE) {
 
   if (length(packages) > 1) {
     if ("R" %in% packages) {
@@ -37,6 +38,10 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
     }
   }
 
+  first.log <- as.Date("2012-10-01") # first RStudio CRAN mirror log.
+  # first.rlog <- as.Date("2014-05-23") # first non-problematic candidate
+  first.r_log <- as.Date("2015-01-01") # match 'cranlogs'
+
   if (!is.null(packages)) {
     if (!"R" %in% packages) {
       if (check.package) {
@@ -45,14 +50,19 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
       first.published <- do.call(c, lapply(packages, function(pkg) {
         packageHistory(pkg)[1, "Date"]
       }))
+      if (any(first.published < first.log)) {
+        first.published[first.published < first.log] <- first.log
+      }
+    } else {
+      first.published <- packageHistory("R")[1, "Date"]
+      if (first.r_log >= first.published) first.published <- first.r_log
     }
-  }
+  } else first.published <- first.log
 
-  cal.date <- logDate(warning.msg = FALSE)
+  cal.date <- logDate(warning.msg = FALSE, fix.date = FALSE)
 
   if (is.null(when) & is.null(from) & is.null(to)) {
     args <- list(packages = packages, from = cal.date, to = cal.date)
-
   } else if (!is.null(when) & is.null(from) & is.null(to)) {
     if (when %in% c("last-day", "last-week", "last-month")) {
       args <- list(packages = packages, when = when)
@@ -60,29 +70,52 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
       stop('"when" must be "last-day", "last-week" or "last-month".',
         call. = FALSE)
       }
-
   } else if (is.null(when) & !is.null(from)) {
     start.date <- resolveDate(from, type = "from")
-
-    if (!is.null(to)) end.date <- resolveDate(to, type = "to")
-    else end.date <- cal.date
-
+    if ("R" %in% packages) {
+      if (start.date < first.r_log) {
+        message("Logs for R download begin ", first.r_log, ".")
+      }
+    }
+    if (!is.null(to)) {
+      end.date <- resolveDate(to, type = "to")
+      end.date.test <- first.published > end.date
+      if (any(end.date.test)) {
+        drop.pkgs <- paste(packages[end.date.test], collapse = ", ")
+        message("Note: ", drop.pkgs, " not published by selected end date.")
+        packages <- packages[!end.date.test]
+        first.published <- first.published[!end.date.test]
+      }
+    } else end.date <- cal.date
     if (start.date > end.date) stop('"from" must be <= "to".', call. = FALSE)
-
     args <- list(packages = packages, from = start.date, to = end.date)
-
   } else if (is.null(when) & !is.null(to)) {
     end.date <- resolveDate(to, type = "to")
-
-    to.data <- lapply(seq_along(packages), function(i) {
-      cranlogs::cran_downloads(packages[i], from = first.published[i],
+    if (is.null(packages)) {
+      to.data <- cranlogs::cran_downloads(NULL, from = first.published,
         to = end.date)
-    })
+    } else {
+      end.date.test <- first.published > end.date
+      if (any(end.date.test)) {
+        drop.pkgs <- paste(packages[end.date.test], collapse = ", ")
+        message("Note: ", drop.pkgs, " not published by selected end date.")
+        packages <- packages[!end.date.test]
+        first.published <- first.published[!end.date.test]
+      }
+      to.data <- lapply(seq_along(packages), function(i) {
+        cranlogs::cran_downloads(packages[i], from = first.published[i],
+          to = end.date)
+      })
+      if ("R" %in% packages) {
+        if (end.date < first.r_log) {
+          stop("Logs for R download begin ", first.r_log, ".", call. = FALSE)
+        }
+      }
+    }
   }
 
   if ("args" %in% ls()) {
     cranlogs.data <- do.call(cranlogs::cran_downloads, args)
-
     if (is.null(args$packages)) {
       cranlogs.data$cumulative <- cumsum(cranlogs.data$count)
     } else if ("R" %in% args$packages) {
@@ -95,26 +128,44 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
       cranlogs.data <- data.frame(date = dts, count = c(count),
         cumulative = c(cumulative), platform = plt, row.names = NULL)
     } else {
-      cumulative <- lapply(unique(cranlogs.data$package), function(pkg) {
+      cumulative <- unlist(lapply(packages, function(pkg) {
         cumsum(cranlogs.data[cranlogs.data$package == pkg, "count"])
-      })
+      }))
       cranlogs.data <- cbind(cranlogs.data[, c("date", "count")],
-        unlist(cumulative), cranlogs.data$package)
+        cumulative, cranlogs.data$package)
       sel <- (ncol(cranlogs.data) - 1):ncol(cranlogs.data)
       names(cranlogs.data)[sel] <- c("cumulative", "package")
     }
     out <- list(packages = packages, cranlogs.data = cranlogs.data,
       when = args$when, from = args$from, to = args$to)
   } else {
-    cranlogs.data <- do.call(rbind, to.data)
+    if (inherits(to.data, "list")) {
+      cranlogs.data <- do.call(rbind, to.data)
+    } else if (inherits(to.data, "data.frame")) {
+      cranlogs.data <- to.data
+    }
 
-    cumulative <- unlist(lapply(unique(cranlogs.data$package), function(pkg) {
-      cumsum(cranlogs.data[cranlogs.data$package == pkg, "count"])
-    }))
-
-    cranlogs.data <- cbind(cranlogs.data[, c("date", "count")], cumulative,
-      cranlogs.data$package)
-    names(cranlogs.data)[ncol(cranlogs.data)] <- "package"
+    if ("R" %in% packages) {
+      cranlogs.data <- cranlogs.data[cranlogs.data$os != "NA", ]
+      count <- tapply(cranlogs.data$count, list(cranlogs.data$date,
+        cranlogs.data$os), sum)
+      cumulative <- apply(count, 2, cumsum)
+      dts <- rep(as.Date(row.names(count)), ncol(count))
+      plt <- rep(colnames(count), each = nrow(count))
+      cranlogs.data <- data.frame(date = dts, count = c(count),
+        cumulative = c(cumulative), platform = plt, row.names = NULL)
+    } else {
+      if (is.null(packages)) {
+        cranlogs.data$cumulative <- cumsum(cranlogs.data$count)
+      } else {
+        cumulative <- unlist(lapply(packages, function(p) {
+          cumsum(cranlogs.data[cranlogs.data$package == p, "count"])
+        }))
+        cranlogs.data <- cbind(cranlogs.data[, c("date", "count")], cumulative,
+          cranlogs.data$package)
+        names(cranlogs.data)[ncol(cranlogs.data)] <- "package"
+      }
+    }
 
     id <- which.min(first.published)
     out <- list(packages = packages, cranlogs.data = cranlogs.data,
@@ -127,6 +178,7 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
     }
   }
 
+  if (fix.cranlogs) out <- fixCranlogs(out)
   class(out) <- "cranDownloads"
   out
 }
@@ -137,7 +189,7 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
 #' @param statistic Character. "count" or "cumulative".
 #' @param graphics Character. "auto", "base" or "ggplot2".
 #' @param points Character of Logical. Plot points. "auto", TRUE, FALSE.
-#' @param log.count Logical. Logarithm of package downloads.
+#' @param log.y Logical. Logarithm of package downloads.
 #' @param smooth Logical. Add smoother.
 #' @param se Logical. Works only with graphics = "ggplot2".
 #' @param f Numeric. smoother window for stats::lowess(). For graphics = "base" only; c.f. stats::lowess(f)
@@ -152,7 +204,7 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
 #' @param ip.legend.location Character. Location of in-progress legend.
 #' @param r.total Logical.
 #' @param dev.mode Logical. Use packageHistory0() to scrape CRAN.
-#' @param unit.observation Character. "year", "month", or "day".
+#' @param unit.observation Character. "year", "month", "week", or "day".
 #' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. You can also specify the number logical cores. Mac and Unix only.
 #' @param ... Additional plotting parameters.
 #' @return A base R or ggplot2 plot.
@@ -166,7 +218,7 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
 #' }
 
 plot.cranDownloads <- function(x, statistic = "count", graphics = "auto",
-  points = "auto", log.count = FALSE, smooth = FALSE, se = FALSE, f = 1/3,
+  points = "auto", log.y = FALSE, smooth = FALSE, se = FALSE, f = 1/3,
   span = 3/4, package.version = FALSE, r.version = FALSE,
   population.plot = FALSE, population.seed = as.numeric(Sys.Date()),
   multi.plot = FALSE, same.xy = TRUE, legend.location = "topleft",
@@ -185,8 +237,21 @@ plot.cranDownloads <- function(x, statistic = "count", graphics = "auto",
     }
   }
 
-  if (is.logical(log.count) == FALSE) {
-    stop("log.count must be TRUE or FALSE.", call. = FALSE)
+  if (!is.null(x$when)) {
+    if (x$when == "last-week" & unit.observation != "day") {
+      stop('With when = "last-week", only unit.observation = "day" available.',
+        call. = FALSE)
+    }
+    if (x$when == "last-month" & unit.observation == "month" &
+      graphics == "ggplot2") {
+        msg1 <- 'With when = "last-month" and graphics = "ggplot2", only'
+        msg2 <- 'unit.observation = "month" is not available.'
+      stop(paste(msg1, msg2), call. = FALSE)
+    }
+  }
+
+  if (is.logical(log.y) == FALSE) {
+    stop("log.y must be TRUE or FALSE.", call. = FALSE)
   }
   if (is.logical(smooth) == FALSE) {
     stop("smooth must be TRUE or FALSE.", call. = FALSE)
@@ -204,9 +269,28 @@ plot.cranDownloads <- function(x, statistic = "count", graphics = "auto",
     stop('graphics must be "base" or "ggplot2"', call. = FALSE)
   }
 
-  if (unit.observation %in% c("month", "year")) {
+  if (unit.observation %in% c("week", "month", "year")) {
+    if (is.null(x$packages)) {
+      x$first.obs.date <- x$cranlogs.data[1, "date"]
+    } else {
+      if ("R" %in% x$packages) {
+        x$first.obs.date <- x$cranlogs.data[1, "date"]
+      } else {
+        x$first.obs.date <- do.call(c, lapply(x$packages, function(pkg) {
+          tmp <- x$cranlogs.data[x$cranlogs.data$package == pkg, ]
+          tmp[1, "date"]
+        }))
+      }
+    }
+
     x$last.obs.date <- x$cranlogs.data[nrow(x$cranlogs.data), "date"]
-    x$cranlogs.data <- aggregateData(unit.observation, x$cranlogs.data, cores)
+
+    if (!is.null(x$when)) {
+      x$from <- x$cranlogs.data$date[1]
+      x$to <- x$cranlogs.data$date[length(x$cranlogs.data$date)]
+    }
+
+    x$cranlogs.data <- aggregateData(x, unit.observation, cores)
   }
 
   obs.ct <- length(unique(x$cranlogs.data$date))
@@ -222,23 +306,23 @@ plot.cranDownloads <- function(x, statistic = "count", graphics = "auto",
        population.seed = population.seed)
   } else if ("R" %in% x$packages) {
     if (r.total) {
-      rTotPlot(x, statistic, graphics, legend.location, points, log.count,
-        smooth, se, r.version, f, span)
+      rTotPlot(x, statistic, graphics, obs.ct, legend.location, points,
+        log.y, smooth, se, r.version, f, span)
     } else {
       rPlot(x, statistic, graphics, obs.ct, legend.location,
-        ip.legend.location, points, log.count, smooth, se, r.version, f, span,
+        ip.legend.location, points, log.y, smooth, se, r.version, f, span,
         multi.plot)
     }
   } else if (is.null(x$packages)) {
-    cranPlot(x, statistic, graphics, points, log.count, smooth, se, f, span,
-      r.version)
+    cranPlot(x, statistic, graphics, obs.ct, points, log.y, smooth, se, f,
+      span, r.version)
   } else {
     if (multi.plot) {
-      multiPlot(x, statistic, graphics, obs.ct, log.count, legend.location,
+      multiPlot(x, statistic, graphics, obs.ct, log.y, legend.location,
         ip.legend.location, points, smooth, se, f, span)
     } else {
       singlePlot(x, statistic, graphics, obs.ct, points, smooth, se, f,
-        span, log.count, package.version, dev.mode, r.version, same.xy)
+        span, log.y, package.version, dev.mode, r.version, same.xy)
     }
   }
 }
