@@ -1,13 +1,13 @@
-#' Re-map filenames (dates) for 2012 download logs.
+#' Re-map filename/URL (date) for 2012 download logs.
 #'
-#' Correct for missing and mis-labeled filenames for 2012 logs at RStudio's CRAN Mirror http://cran-logs.rstudio.com/.
+#' To get the "right" log.
 #' @param date Character. Date. "yyyy-mm-dd".
 #' @note This date problem does not affect \code{cranDownlaods()}.
 #' @return A one unit R date or character vector.
 #' @noRd
 
 fixDate_2012 <- function(date = "2012-12-31") {
-  if (class(date) != "Date") ymd <- as.Date(date)
+  if (!inherits(date, "Date")) ymd <- as.Date(date)
   else ymd <- date
 
   if (format(ymd, "%Y") == "2012") {
@@ -31,3 +31,25 @@ fixDate_2012 <- function(date = "2012-12-31") {
   }
   ymd
 }
+
+#' Reverse map filename/URL (date for 2012 download logs.
+#'
+#' To print the desired/expected date.
+#' @param file.url.date Date. "yyyy-mm-dd".
+#' @return A one unit R date vector.
+#' @noRd
+
+rev_fixDate_2012 <- function(file.url.date) {
+  offset.date <- file.url.date >= as.Date("2012-10-16") &
+                 file.url.date <= as.Date("2012-12-31")
+
+  if (offset.date) ymd <- file.url.date - 3L
+  else ymd <- file.url.date
+
+  if (file.url.date == as.Date("2012-10-12")) {
+    ymd <- as.Date("2012-10-11")
+  } else if (file.url.date == as.Date("2012-10-14")) {
+    ymd <- as.Date("2012-10-12")
+  }
+  ymd
+}
